eventChannel property
The event channel used to receive events from the native platform.
Implementation
@visibleForTesting
final eventChannel = const EventChannel('speech_to_text_pro_events');
The event channel used to receive events from the native platform.
@visibleForTesting
final eventChannel = const EventChannel('speech_to_text_pro_events');