SpeechToTextProWeb class

A web implementation of the SpeechToTextProPlatform of the SpeechToTextPro plugin.

Inheritance

Constructors

SpeechToTextProWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
onError Stream<String>
no setteroverride
onFinalResults Stream<String>
no setteroverride
onListeningStateChanged Stream<bool>
no setteroverride
onPartialResults Stream<String>
no setteroverride
onSpeechEnded Stream<void>
no setterinherited
onSpeechStarted Stream<void>
no setterinherited
onVolumeChanged Stream<double>
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() Future<void>
inherited
getLocales() Future<List<String>>
inherited
hasPermission() Future<bool>
inherited
initialize() Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() Future<void>
inherited
resume() Future<void>
inherited
start({String localeId = 'en-US', bool continuous = false}) Future<void>
override
stop() Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void